@@ -12,27 +12,36 @@ class SettingsMenu(QMenu):
         return action
 
 
+class ThemeMenu(QMenu):
+    def __init__(self, parent=None) -> None:
+        super().__init__(parent=parent)
+        self.setTitle('Theme')
+
+        self.addAction('Light').triggered.connect(lambda: QApplication.instance().change_theme('light'))
+        self.addAction('Dark').triggered.connect(lambda: QApplication.instance().change_theme('dark'))
+
+
 class BaseMainWindow(QMainWindow):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-            
-        self.setObjectName("MainWindow")
+
+        self.setObjectName('MainWindow')
         self.load_settings()
 
     def closeEvent(self, event):
         self.save_settings()
         super().closeEvent(event)
-        
+
     def save_settings(self):
-        QSettings().setValue("mainwindow/geometry", self.saveGeometry())
-        QSettings().setValue("mainwindow/state", self.saveState())
+        QSettings().setValue('mainwindow/geometry', self.saveGeometry())
+        QSettings().setValue('mainwindow/state', self.saveState())
 
     def load_settings(self):
-        geometry = QSettings().value("mainwindow/geometry")
+        geometry = QSettings().value('mainwindow/geometry')
         if isinstance(geometry, QByteArray):
             self.restoreGeometry(geometry)
-        
-        state = QSettings().value("mainwindow/state")
+
+        state = QSettings().value('mainwindow/state')
         if isinstance(state, QByteArray):
             self.restoreState(state)
 
@@ -48,4 +57,4 @@ class BaseMainWindow(QMainWindow):
         self.settings_btn.setMenu(self.settings_menu)
         self.settings_btn.setPopupMode(QToolButton.InstantPopup)
 
-        self.statusbar.addWidget(self.settings_btn)
\ No newline at end of file
+        self.statusbar.addWidget(self.settings_btn)
